@@ -23,10 +23,10 @@ from pymatgen.electronic_structure.bandstructure import \
 import matplotlib as mpl
 mpl.use('Agg')
 
-from sumo.io.questaal import QuestaalInit, QuestaalSite, labels_from_syml
+from sumo.io.questaal import QuestaalSite, labels_from_syml
 from sumo.io.questaal import band_structure as questaal_band_structure
 from sumo.io.castep import band_structure as castep_band_structure
-from sumo.io.castep import read_tdos as read_castep_tdos
+from sumo.io.castep import read_dos as read_castep_dos
 from sumo.plotting.bs_plotter import SBSPlotter
 from sumo.plotting.dos_plotter import SDOSPlotter
 from sumo.electronic_structure.dos import load_dos
@@ -47,6 +47,7 @@ __date__ = "July 18, 2017"
 
 def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
              vbm_cbm_marker=False, projection_selection=None, mode='rgb',
+             normalise="all",
              interpolate_factor=4, circle_size=150, dos_file=None,
              cart_coords=False, scissor=None,
              ylabel='Energy (eV)', dos_label=None,
@@ -123,6 +124,16 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
                     series of stacked circles, with the colour depending on
                     the composition of the band. The size of the circles
                     can be scaled using the ``circle_size`` option.
+
+        normalise (:obj:`str`, optional): Normalisation the projections.
+            Options are:
+
+              * ``'all'``: Projections normalised against the sum of all
+                   other projections.
+              * ``'select'``: Projections normalised against the sum of the
+                   selected projections.
+              * ``None``: No normalisation performed.
+
         circle_size (:obj:`float`, optional): The area of the circles used
             when ``mode = 'stacked'``.
         cart_coords (:obj:`bool`, optional): Whether the k-points are read as
@@ -239,11 +250,11 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
         bs = get_reconstructed_band_structure(bandstructures)
     elif code == 'castep':
         for bands_file in filenames:
-            cell_file = bands_file.replace('bands', 'cell')
+            cell_file = _replace_ext(bands_file, 'cell')
             if os.path.isfile(cell_file):
-                logging.info('found cell file {}...'.format(cell_file))
+                logging.info('Found cell file {}...'.format(cell_file))
             else:
-                logging.info('did not find cell file {}...'.format(cell_file))
+                logging.info('Did not find cell file {}...'.format(cell_file))
                 cell_file = None
             bs = castep_band_structure(bands_file, cell_file=cell_file)
             bandstructures.append(bs)
@@ -300,12 +311,29 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
     dos_opts = None
     if dos_file:
         if code == 'vasp':
-            dos, pdos = load_dos(dos_file, elements, lm_orbitals, atoms, gaussian,
-                                 total_only)
+            dos, pdos = load_dos(dos_file, elements, lm_orbitals,
+                                 atoms, gaussian, total_only)
         elif code == 'castep':
-            dos = read_castep_tdos(dos_file, gaussian=gaussian,
-                                   efermi_to_vbm=True, emin=ymin, emax=ymax)
-            pdos = {}
+            pdos_file = None
+            if cell_file:
+                pdos_file = _replace_ext(cell_file, 'pdos_bin')
+                if not os.path.isfile(pdos_file):
+                    pdos_file = None
+                    logging.info(f"PDOS file {pdos_file} does not exist, "
+                                 "falling back to TDOS.")
+                else:
+                    logging.info(f"Found PDOS file {pdos_file}")
+            else:
+                logging.info(f"Cell file {cell_file} does not exist, "
+                             "cannot plot PDOS.")
+
+            dos, pdos = read_castep_dos(dos_file, pdos_file=pdos_file,
+                                        cell_file=cell_file,
+                                        gaussian=gaussian,
+                                        lm_orbitals=lm_orbitals,
+                                        elements=elements,
+                                        efermi_to_vbm=True)
+
         dos_plotter = SDOSPlotter(dos, pdos)
         dos_opts = {'plot_total': plot_total, 'legend_cutoff': legend_cutoff,
                     'colours': colours, 'yscale': yscale}
@@ -313,11 +341,11 @@ def bandplot(filenames=None, code='vasp', prefix=None, directory=None,
     if scissor:
         bs = bs.apply_scissor(scissor)
 
-    spin = string_to_spin(spin) # Convert spin argument to pymatgen Spin object
+    spin = string_to_spin(spin)  # Convert spin name to pymatgen Spin object
     plotter = SBSPlotter(bs)
     if projection_selection:
         plt = plotter.get_projected_plot(
-            projection_selection, mode=mode,
+            projection_selection, mode=mode, normalise=normalise,
             interpolate_factor=interpolate_factor, circle_size=circle_size,
             zero_to_efermi=True, ymin=ymin, ymax=ymax, height=height,
             width=width, vbm_cbm_marker=vbm_cbm_marker, ylabel=ylabel,
@@ -445,6 +473,20 @@ def _el_orb_tuple(string):
     return el_orbs
 
 
+def _replace_ext(string, new_ext):
+    """Replace file extension
+
+    Args:
+        string (`str`): The file name with extensions to be replace
+        new_ext (`str`): The new extension
+
+    Returns:
+        A string with files extension replaced by new_ext
+    """
+    name, _ = os.path.splitext(string)
+    return name + '.' + new_ext
+
+
 def _get_parser():
     parser = argparse.ArgumentParser(description="""
     bandplot is a script to produce publication-ready band
@@ -474,6 +516,9 @@ def _get_parser():
     parser.add_argument('--mode', default='rgb', type=str,
                         help=('mode for orbital projections (options: rgb, '
                               'stacked)'))
+    parser.add_argument('--normalise', default='rgb', type=str,
+                        help=('how to normalise projections (options: all, '
+                              'select)'))
     parser.add_argument('--interpolate-factor', type=int, default=4,
                         dest='interpolate_factor', metavar='N',
                         help=('interpolate factor for band structure '
@@ -502,8 +547,9 @@ def _get_parser():
     parser.add_argument('--atoms', type=_atoms, metavar='A',
                         help=('atoms to include (e.g. "O.1.2.3,Ru.1.2.3")'))
     parser.add_argument('--spin', type=str, default=None,
-                        help=('select only one spin channel for a spin-polarised '
-                              'calculation (options: up, 1; down, -1)'))
+                        help=('select only one spin channel for a '
+                              'spin-polarised calculation '
+                              '(options: up, 1; down, -1)'))
     parser.add_argument('--scissor', type=float, default=None, dest='scissor',
                         help='apply scissor operator')
     parser.add_argument('--total-only', action='store_true', dest='total_only',
@@ -568,6 +614,7 @@ def main():
     bandplot(filenames=args.filenames, code=args.code, prefix=args.prefix,
              directory=args.directory, vbm_cbm_marker=args.band_edges,
              projection_selection=args.projection_selection, mode=args.mode,
+             normalise=args.normalise,
              interpolate_factor=args.interpolate_factor,
              cart_coords=args.cartesian, scissor=args.scissor,
              circle_size=args.circle_size, yscale=args.scale,
